===============
 pubtools-sign
===============

Set of scripts used for signing 


Requirements
============

* Python 3.7+

Features
========
* pubtools-sign
* pubtools-sign-clearsign 
* pubtools-sign-containersign 

Setup
=====

::

  $ pip install -r requirements.txt
  $ pip install . 
  or
  $ python setup.py install

Usage
=====
